==> massxpert2_8.4.1.orig.tar.gz: massxpert2-8.4.1/src/gui/MzLabInputOligomerTableViewModel.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
#define MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
// #pragma message("including MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP")

/////////////////////// Qt includes
#include <QTableView>


/////////////////////// Local includes
#include "libmass/Oligomer.hpp"
#include "MzLabInputOligomerTableViewDlg.hpp"
#include "MzLabWnd.hpp"


namespace msxps
{

	namespace massxpert
	{



enum
{
  MZ_LAB_INPUT_OLIGO_MASS_COLUMN,
  MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN,
  MZ_LAB_INPUT_OLIGO_NAME_COLUMN,
  MZ_LAB_INPUT_OLIGO_COORDS_COLUMN,
  MZ_LAB_INPUT_OLIGO_TOTAL_COLUMNS
};


class MzLabInputOligomerTableViewModel : public QAbstractTableModel
{
  Q_OBJECT

  private:
  OligomerList *mp_oligomerList;

  MzLabInputOligomerTableView *mp_tableView;

  MzLabWnd *mp_mzLabWnd;
  MzLabInputOligomerTableViewDlg *mp_parentDlg;

  // Fixme: does not this belong to the dialog? Maybe a pointer to
  // the other one should be better.
  libmass::MassType m_massType;

  public:
  MzLabInputOligomerTableViewModel(OligomerList *, QObject *);
  ~MzLabInputOligomerTableViewModel();

  void setParentDlg(MzLabInputOligomerTableViewDlg *);
  MzLabInputOligomerTableViewDlg *parentDlg();

  void setMzLabWnd(MzLabWnd *);
  MzLabWnd *mzLabWnd();

  const OligomerList *oligomerList() const;

  void setTableView(MzLabInputOligomerTableView *);
  MzLabInputOligomerTableView *tableView();

  int rowCount(const QModelIndex &parent = QModelIndex()) const;
  int columnCount(const QModelIndex &parent = QModelIndex()) const;

  QVariant headerData(int, Qt::Orientation, int role = Qt::DisplayRole) const;

  bool setData(const QModelIndex &, const QVariant &, int role = Qt::EditRole);

  QVariant data(const QModelIndex &parent = QModelIndex(),
                int role                  = Qt::DisplayRole) const;

  int addOligomer(libmass::OligomerSPtr oligomer_sp);
  int removeOligomers(int, int);
};

} // namespace massxpert

} // namespace msxps


#endif // MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
// #pragma message("done...including
// MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP")

==> massxpert_6.0.1.orig.tar.gz: massxpert-6.0.1/src/gui/MzLabInputOligomerTableViewModel.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
#define MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
// #pragma message("including MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP")

/////////////////////// Qt includes
#include <QTableView>


/////////////////////// Local includes
#include "../nongui/Oligomer.hpp"
#include "MzLabInputOligomerTableViewDlg.hpp"
#include "MzLabWnd.hpp"


namespace msxps
{

	namespace massxpert
	{



enum
{
  MZ_LAB_INPUT_OLIGO_MASS_COLUMN,
  MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN,
  MZ_LAB_INPUT_OLIGO_NAME_COLUMN,
  MZ_LAB_INPUT_OLIGO_COORDS_COLUMN,
  MZ_LAB_INPUT_OLIGO_TOTAL_COLUMNS
};


class MzLabInputOligomerTableViewModel : public QAbstractTableModel
{
  Q_OBJECT

  private:
  OligomerList *mp_oligomerList;

  MzLabInputOligomerTableView *mp_tableView;

  MzLabWnd *mp_mzLabWnd;
  MzLabInputOligomerTableViewDlg *mp_parentDlg;

  // Fixme: does not this belong to the dialog? Maybe a pointer to
  // the other one should be better.
  MassType m_massType;

  public:
  MzLabInputOligomerTableViewModel(OligomerList *, QObject *);
  ~MzLabInputOligomerTableViewModel();

  void setParentDlg(MzLabInputOligomerTableViewDlg *);
  MzLabInputOligomerTableViewDlg *parentDlg();

  void setMzLabWnd(MzLabWnd *);
  MzLabWnd *mzLabWnd();

  const OligomerList *oligomerList() const;

  void setTableView(MzLabInputOligomerTableView *);
  MzLabInputOligomerTableView *tableView();

  int rowCount(const QModelIndex &parent = QModelIndex()) const;
  int columnCount(const QModelIndex &parent = QModelIndex()) const;

  QVariant headerData(int, Qt::Orientation, int role = Qt::DisplayRole) const;

  bool setData(const QModelIndex &, const QVariant &, int role = Qt::EditRole);

  QVariant data(const QModelIndex &parent = QModelIndex(),
                int role                  = Qt::DisplayRole) const;

  int addOligomer(Oligomer *);
  int removeOligomers(int, int);
};

} // namespace massxpert

} // namespace msxps


#endif // MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
// #pragma message("done...including
// MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP")
